@@ -1,4 +1,7 @@
-use crate::{config::ModelSource, Error, Result};
+use crate::{
+    config::ModelSource,
+    error::{Error, Result},
+};
 use atelier_core::model::Model;
 use reqwest::Url;
 use rustc_hash::FxHasher;
@@ -257,7 +260,9 @@ fn urls_to_cached_files(urls: Vec<String>) -> Result<Vec<PathBuf>> {
     }
     if results.len() != urls.len() {
         Err(Error::Other(format!(
-            "Quitting - {} model files could not be downloaded and were not found in the cache. If you have previously built this project and are working \"offline\", try setting SMITHY_CACHE=NO_EXPIRE in the environment",
+            "Quitting - {} model files could not be downloaded and were not found in the cache. \
+             If you have previously built this project and are working \"offline\", try setting \
+             SMITHY_CACHE=NO_EXPIRE in the environment",
             urls.len() - results.len()
         )))
     } else {
